local TStructureUnit = import('/lua/terranunits.lua').TStructureUnit
local WeaponFile = import('/lua/sim/DefaultWeapons.lua')
local DefaultBeamWeapon = WeaponFile.DefaultBeamWeapon
local CollisionBeam = import('/lua/sim/CollisionBeam.lua').CollisionBeam
local EffectTemplate = import('/lua/EffectTemplates.lua')

SCCollisionBeam = Class(CollisionBeam) {
    FxImpactUnit = EffectTemplate.DefaultProjectileLandUnitImpact,
    FxImpactLand = {},#EffectTemplate.DefaultProjectileLandImpact,
    FxImpactWater = EffectTemplate.DefaultProjectileWaterImpact,
    FxImpactUnderWater = EffectTemplate.DefaultProjectileUnderWaterImpact,
    FxImpactAirUnit = EffectTemplate.DefaultProjectileAirUnitImpact,
    FxImpactProp = {},
    FxImpactShield = {},    
    FxImpactNone = {},
}

ls_konata01_Beam = Class(SCCollisionBeam) {
    FxBeam = {
		'/mods/Lucky Star/effects/emitters/ls_konata01_Beam.bp',
	},
    FxBeamEndPoint = {
		'/mods/Lucky Star/effects/emitters/ls_konata01_BeamEndPoint.bp',
	},
    FxBeamEndPointScale = 1,
}

ls_konata01_Weapon = Class(DefaultBeamWeapon) {
    BeamType = ls_konata01_Beam,
	
    FxMuzzleFlash = {'/mods/Lucky Star/effects/emitters/ls_konata01_Muzzle.bp'},
}

ls_konata01 = Class(TStructureUnit) {
	
	
    Weapons = {
        Mekara_Beam = Class(ls_konata01_Weapon) {}
    },
	
	OnCreate = function(self)
		TStructureUnit.OnCreate(self)
		
		self.hasSounds = false
		self.fullyBuilt = false
		
		if DiskGetFileInfo('/sounds/LuckyStar.xsb') and DiskGetFileInfo('/sounds/LuckyStar.xwb') then
			self.hasSounds = true
		end
	end,
	
	OnStopBeingBuilt = function(self,builder,layer)
        TStructureUnit.OnStopBeingBuilt(self,builder,layer)
		
		self.fullyBuilt = true
		
		if self.hasSounds then
	        local sound = Sound({Cue = 'start', Bank = 'LuckyStar'})
			self:PlaySound(sound)
		end
	end,
	
	OnKilled = function(self, instigator, type, overkillRatio)
		if self.hasSounds and self.fullyBuilt then
	        local sound = Sound({Cue = 'shutdown', Bank = 'LuckyStar'})
			self:PlaySound(sound)
		end
		
        TStructureUnit.OnKilled(self, instigator, type, overkillRatio)
    end,
}

TypeClass = ls_konata01